/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.pvm.impl;

import java.io.Serializable;
import java.util.Date;
import java.util.Set;

import org.jbpm.env.Environment;
import org.jbpm.pvm.Comment;
import org.jbpm.pvm.Execution;
import org.jbpm.util.Clock;
import org.jbpm.util.EqualsUtil;

public class CommentImpl implements Serializable, Comment {

  private static final long serialVersionUID = 1L;

  protected long dbid;
  protected int dbversion;
  protected String actorId = null;
  protected Date time = null;
  protected String message = null;
  protected ExecutionImpl execution = null;
  protected CommentImpl parent;
  protected Set<CommentImpl> children = null;

  public CommentImpl() {
  }

  public CommentImpl(String message, Execution execution) {
    this.message = message;
    this.execution = (ExecutionImpl) execution;
    this.time = Clock.getCurrentTime();
    
    Environment environment = Environment.getCurrent();
    if (environment!=null) {
      this.actorId = environment.getUserId();
    }
  }

  // equals ///////////////////////////////////////////////////////////////////
  // hack to support comparing hibernate proxies against the real objects
  // since this always falls back to ==, we don't need to overwrite the hashcode
  public boolean equals(Object o) {
    return EqualsUtil.equals(this, o);
  }

  // getters and setters //////////////////////////////////////////////////////

  public long getDbid() {
    return dbid;
  }
  public void setExecution(ExecutionImpl execution) {
    this.execution = execution;
  }
  public String getActorId() {
    return actorId;
  }
  public String getMessage() {
    return message;
  }
  public Date getTime() {
    return time;
  }
  public Execution getExecution() {
    return execution;
  }
  public void setActorId(String actorId) {
    this.actorId = actorId;
  }
  public void setTime(Date time) {
    this.time = time;
  }
  public void setMessage(String message) {
    this.message = message;
  }
  public Comment getParent() {
    return parent;
  }
  public void setParent(CommentImpl parent) {
    this.parent = parent;
  }
  public Set<Comment> getChildren() {
    return (Set) children;
  }
  public void setChildren(Set<CommentImpl> children) {
    this.children = children;
  }
}
