/**
 * Copyright (C) 2007  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.novabpm.identity;

/**
 * @author "Pierre Vigneras"
 * @date Dec 14, 2007
 */
public class UserNotFoundException extends Exception {
  private final String id;

  private final UserOp user;

  public UserNotFoundException(String id) {
    super("Can't find a user mapped to id: " + id);
    if (id == null)
      throw new IllegalArgumentException("id is null!");
    this.id = id;
    this.user = null;
  }

  public UserNotFoundException(UserOp user) {
    super("Can't find a user mapped to id: " + user.getId()
        + " -- Given user: " + user + "may have been removed!");
    if (user == null)
      throw new IllegalArgumentException("user is null!");
    this.user = user;
    this.id = user.getId();
  }

  /**
   * Return the user that has not been found. May be null.
   * 
   * @return the user that has not been found. May be null.
   */
  public UserOp getUser() {
    return user;
  }

  /**
   * Return the id that is was not mapped to any user. Cannot be null.
   * 
   * @return the id that is was not mapped to any user. Cannot be null.
   */
  public String getId() {
    return id;
  }
}
